
# example1 schema





### Classes

 * [HasMessagesClass](HasMessagesClass.md)
     * [HasMessagesChild](HasMessagesChild.md)
 * [MetricResult](MetricResult.md) - Result of executing a metric on a KS
     * [MetricResultChild](MetricResultChild.md)
 * [Problem](Problem.md) - An object representing an error or problem encountered
     * [DownloadProblem](DownloadProblem.md) - A problem in downloading a knowledge source

### Mixins


### Slots

 * [description](description.md)
 * [evaluated using](evaluated_using.md)
 * [has child messages](has_child_messages.md)
 * [has messages](has_messages.md)
 * [has source](has_source.md)
 * [has status](has_status.md)
 * [lone slot joe](lone_slot_joe.md)
 * [result child slot](result_child_slot.md)

### Enums


### Subsets


### Types


#### Built in

 * **str**

#### Defined

 * [String](types/String.md)  (**str**) 
